data = [
    {
        'code': '169',
        'city': 'آذرشهر',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '170',
        'city': 'اسکو',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '149-150',
        'city': 'اهر',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '171',
        'city': 'بستان آباد',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '168',
        'city': 'بناب',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '136-137-138',
        'city': 'تبریز',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '545',
        'city': 'ترکمانچای',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '505',
        'city': 'جلفا',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '636',
        'city': 'چاروایماق',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '164-165',
        'city': 'سراب',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '172',
        'city': 'شبستر',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '623',
        'city': 'صوفیان',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '506',
        'city': 'عجب شیر',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '519',
        'city': 'کلیبر',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '154-155',
        'city': 'مراغه',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '567',
        'city': 'ورزقان',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '173',
        'city': 'هریس',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '159-160',
        'city': 'هشترود',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '604',
        'city': 'هوراند',
        'province': 'آذربایجان شرقی'
    },
    {
        'code': '274-275',
        'city': 'ارومیه',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '295',
        'city': 'اشنویه',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '637',
        'city': 'انزل',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '292',
        'city': 'بوکان',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '492',
        'city': 'پلدشت',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '289',
        'city': 'پیرانشهر',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '677',
        'city': 'تخت سلیمان',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '294',
        'city': 'تکاب',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '493',
        'city': 'چایپاره',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '279-280',
        'city': 'خوی',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '288',
        'city': 'سردشت',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '284-285',
        'city': 'سلماس',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '638',
        'city': 'سیلوانه',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '291',
        'city': 'سیه چشمه(چالدران)',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '640',
        'city': 'شوط',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '293',
        'city': 'شاهین دژ',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '675',
        'city': 'کشاورز',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '282-283',
        'city': 'ماکو',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '286-287',
        'city': 'مهاباد',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '296-297',
        'city': 'میاندوآب',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '290',
        'city': 'نقده',
        'province': 'آذربایجان غربی'
    },
    {
        'code': '400-401',
        'city': 'اسدآباد',
        'province': 'همدان'
    },
    {
        'code': '404-405',
        'city': 'بهار',
        'province': 'همدان'
    },
    {
        'code': '397',
        'city': 'تویسرکان',
        'province': 'همدان'
    },
    {
        'code': '398-399',
        'city': 'رزن',
        'province': 'همدان'
    },
    {
        'code': '647',
        'city': 'شراء و پیشخوار',
        'province': 'همدان'
    },
    {
        'code': '502',
        'city': 'فامنین',
        'province': 'همدان'
    },
    {
        'code': '584',
        'city': 'قلقل رود',
        'province': 'همدان'
    },
    {
        'code': '402-403',
        'city': 'کبودرآهنگ',
        'province': 'همدان'
    },
    {
        'code': '392-393',
        'city': 'ملایر',
        'province': 'همدان'
    },
    {
        'code': '395-396',
        'city': 'نهاوند',
        'province': 'همدان'
    },
    {
        'code': '386-387',
        'city': 'همدان',
        'province': 'همدان'
    },
    {
        'code': '503',
        'city': 'ابرکوه',
        'province': 'یزد'
    },
    {
        'code': '444',
        'city': 'اردکان',
        'province': 'یزد'
    },
    {
        'code': '551',
        'city': 'اشکذر',
        'province': 'یزد'
    },
    {
        'code': '447',
        'city': 'بافق',
        'province': 'یزد'
    },
    {
        'code': '561',
        'city': 'بهاباد',
        'province': 'یزد'
    },
    {
        'code': '445',
        'city': 'تفت',
        'province': 'یزد'
    },
    {
        'code': '718',
        'city': 'دستگردان',
        'province': 'یزد'
    },
    {
        'code': '083',
        'city': 'طبس',
        'province': 'یزد'
    },
    {
        'code': '446',
        'city': 'مهریز',
        'province': 'یزد'
    },
    {
        'code': '448',
        'city': 'میبد',
        'province': 'یزد'
    },
    {
        'code': '552',
        'city': 'نیر',
        'province': 'یزد'
    },
    {
        'code': '543',
        'city': 'هرات و مروست',
        'province': 'یزد'
    },
    {
        'code': '442-443',
        'city': 'یزد',
        'province': 'یزد'
    },
    {
        'code': '051',
        'city': 'آشتیان',
        'province': 'مرکزی'
    },
    {
        'code': '052-053',
        'city': 'اراک',
        'province': 'مرکزی'
    },
    {
        'code': '058',
        'city': 'تفرش',
        'province': 'مرکزی'
    },
    {
        'code': '055',
        'city': 'خمین',
        'province': 'مرکزی'
    },
    {
        'code': '617',
        'city': 'خنداب',
        'province': 'مرکزی'
    },
    {
        'code': '057',
        'city': 'دلیجان',
        'province': 'مرکزی'
    },
    {
        'code': '618',
        'city': 'زرند مرکزی',
        'province': 'مرکزی'
    },
    {
        'code': '059-060',
        'city': 'ساوه',
        'province': 'مرکزی'
    },
    {
        'code': '061-062',
        'city': 'سربند',
        'province': 'مرکزی'
    },
    {
        'code': '544',
        'city': 'فراهان',
        'province': 'مرکزی'
    },
    {
        'code': '056',
        'city': 'محلات',
        'province': 'مرکزی'
    },
    {
        'code': '571',
        'city': 'وفس',
        'province': 'مرکزی'
    },
    {
        'code': '593',
        'city': 'هندودر',
        'province': 'مرکزی'
    },
    {
        'code': '667',
        'city': 'ابوموسی',
        'province': 'هرمزگان'
    },
    {
        'code': '348',
        'city': 'بستک',
        'province': 'هرمزگان'
    },
    {
        'code': '586',
        'city': 'بشاگرد',
        'province': 'هرمزگان'
    },
    {
        'code': '338-339',
        'city': 'بندرعباس',
        'province': 'هرمزگان'
    },
    {
        'code': '343-344',
        'city': 'بندرلنگه',
        'province': 'هرمزگان'
    },
    {
        'code': '346',
        'city': 'جاسک',
        'province': 'هرمزگان'
    },
    {
        'code': '337',
        'city': 'حاجی آباد',
        'province': 'هرمزگان'
    },
    {
        'code': '554',
        'city': 'خمیر',
        'province': 'هرمزگان'
    },
    {
        'code': '469',
        'city': 'رودان',
        'province': 'هرمزگان'
    },
    {
        'code': '537',
        'city': 'فین',
        'province': 'هرمزگان'
    },
    {
        'code': '345',
        'city': 'قشم',
        'province': 'هرمزگان'
    },
    {
        'code': '470',
        'city': 'گاوبندی',
        'province': 'هرمزگان'
    },
    {
        'code': '341-342',
        'city': 'میناب',
        'province': 'هرمزگان'
    },
    {
        'code': ' 483-484',
        'city': 'ازنا',
        'province': 'لرستان'
    },
    {
        'code': '557',
        'city': 'اشترینان',
        'province': 'لرستان'
    },
    {
        'code': '418',
        'city': 'الشتر',
        'province': 'لرستان'
    },
    {
        'code': '416-417',
        'city': 'الیگودرز',
        'province': 'لرستان'
    },
    {
        'code': '412-413',
        'city': 'بروجرد',
        'province': 'لرستان'
    },
    {
        'code': '592',
        'city': 'پاپی',
        'province': 'لرستان'
    },
    {
        'code': '612',
        'city': 'چغلوندی',
        'province': 'لرستان'
    },
    {
        'code': '613',
        'city': 'چگنی',
        'province': 'لرستان'
    },
    {
        'code': '406-407',
        'city': 'خرم آباد',
        'province': 'لرستان'
    },
    {
        'code': '421',
        'city': 'دورود',
        'province': 'لرستان'
    },
    {
        'code': '598',
        'city': 'رومشکان',
        'province': 'لرستان'
    },
    {
        'code': '419',
        'city': 'کوهدشت',
        'province': 'لرستان'
    },
    {
        'code': '385',
        'city': 'ملاوی(پلدختر)',
        'province': 'لرستان'
    },
    {
        'code': '420',
        'city': 'نورآباد(دلفان)',
        'province': 'لرستان'
    },
    {
        'code': '528',
        'city': 'ویسیان',
        'province': 'لرستان'
    },
    {
        'code': '213-214',
        'city': 'آمل',
        'province': 'مازندران'
    },
    {
        'code': '205-206',
        'city': 'بابل',
        'province': 'مازندران'
    },
    {
        'code': '498',
        'city': 'بابل',
        'province': 'مازندران'
    },
    {
        'code': '568',
        'city': 'بندپی',
        'province': 'مازندران'
    },
    {
        'code': '711',
        'city': 'بندپی شرقی',
        'province': 'مازندران'
    },
    {
        'code': '217-218',
        'city': 'بهشهر',
        'province': 'مازندران'
    },
    {
        'code': '221',
        'city': 'تنکابن',
        'province': 'مازندران'
    },
    {
        'code': '582',
        'city': 'جویبار',
        'province': 'مازندران'
    },
    {
        'code': '483',
        'city': 'چالوس',
        'province': 'مازندران'
    },
    {
        'code': '625',
        'city': 'چمستان',
        'province': 'مازندران'
    },
    {
        'code': '576',
        'city': 'چهاردانگه',
        'province': 'مازندران'
    },
    {
        'code': '578',
        'city': 'دودانگه',
        'province': 'مازندران'
    },
    {
        'code': '227',
        'city': 'رامسر',
        'province': 'مازندران'
    },
    {
        'code': '208-209',
        'city': 'ساری',
        'province': 'مازندران'
    },
    {
        'code': '225',
        'city': 'سوادکوه',
        'province': 'مازندران'
    },
    {
        'code': '577',
        'city': 'شیرگاه',
        'province': 'مازندران'
    },
    {
        'code': '712',
        'city': 'عباس آباد',
        'province': 'مازندران'
    },
    {
        'code': '215-216',
        'city': 'قائمشهر',
        'province': 'مازندران'
    },
    {
        'code': '626',
        'city': 'کجور',
        'province': 'مازندران'
    },
    {
        'code': '627',
        'city': 'کلاردشت',
        'province': 'مازندران'
    },
    {
        'code': '579',
        'city': 'گلوگاه',
        'province': 'مازندران'
    },
    {
        'code': '713',
        'city': 'میاندورود',
        'province': 'مازندران'
    },
    {
        'code': '499',
        'city': 'نکاء',
        'province': 'مازندران'
    },
    {
        'code': '222',
        'city': 'نور',
        'province': 'مازندران'
    },
    {
        'code': '219-220',
        'city': 'نوشهر',
        'province': 'مازندران'
    },
    {
        'code': '500-501',
        'city': 'هراز و محمودآباد',
        'province': 'مازندران'
    },
    {
        'code': '623',
        'city': 'آزادشهر',
        'province': 'گلستان'
    },
    {
        'code': '497',
        'city': 'آق قلا',
        'province': 'گلستان'
    },
    {
        'code': '223',
        'city': 'بندرترکمن',
        'province': 'گلستان'
    },
    {
        'code': '689',
        'city': 'بندرگز',
        'province': 'گلستان'
    },
    {
        'code': '487',
        'city': 'رامیان',
        'province': 'گلستان'
    },
    {
        'code': '226',
        'city': 'علی آباد',
        'province': 'گلستان'
    },
    {
        'code': '224',
        'city': 'کردکوی',
        'province': 'گلستان'
    },
    {
        'code': '386',
        'city': 'کلاله',
        'province': 'گلستان'
    },
    {
        'code': '211-212',
        'city': 'گرگان',
        'province': 'گلستان'
    },
    {
        'code': '628',
        'city': 'گمیشان',
        'province': 'گلستان'
    },
    {
        'code': '202-203',
        'city': 'گنبد کاووس',
        'province': 'گلستان'
    },
    {
        'code': '531',
        'city': 'مراوه تپه',
        'province': 'گلستان'
    },
    {
        'code': '288',
        'city': 'مینودشت',
        'province': 'گلستان'
    },
    {
        'code': '261',
        'city': 'آستارا',
        'province': 'گیلان'
    },
    {
        'code': '273',
        'city': 'آستانه',
        'province': 'گیلان'
    },
    {
        'code': '630',
        'city': 'املش',
        'province': 'گیلان'
    },
    {
        'code': '264',
        'city': 'بندرانزلی',
        'province': 'گیلان'
    },
    {
        'code': '518',
        'city': 'خمام',
        'province': 'گیلان'
    },
    {
        'code': '631',
        'city': 'رحیم آباد',
        'province': 'گیلان'
    },
    {
        'code': '258-259',
        'city': 'رشت',
        'province': 'گیلان'
    },
    {
        'code': '570',
        'city': 'رضوانشهر',
        'province': 'گیلان'
    },
    {
        'code': '265',
        'city': 'رودبار',
        'province': 'گیلان'
    },
    {
        'code': '268-269',
        'city': 'رودسر',
        'province': 'گیلان'
    },
    {
        'code': '653',
        'city': 'سنگر',
        'province': 'گیلان'
    },
    {
        'code': '517',
        'city': 'سیاهکل',
        'province': 'گیلان'
    },
    {
        'code': '569',
        'city': 'شفت',
        'province': 'گیلان'
    },
    {
        'code': '267',
        'city': 'صومعه سرا',
        'province': 'گیلان'
    },
    {
        'code': '262-263',
        'city': 'طالش',
        'province': 'گیلان'
    },
    {
        'code': '593',
        'city': 'عمارلو',
        'province': 'گیلان'
    },
    {
        'code': '266',
        'city': 'فومن',
        'province': 'گیلان'
    },
    {
        'code': '693',
        'city': 'کوچصفهان',
        'province': 'گیلان'
    },
    {
        'code': '271-272',
        'city': 'لاهیجان',
        'province': 'گیلان'
    },
    {
        'code': '694',
        'city': 'لشت نشاء',
        'province': 'گیلان'
    },
    {
        'code': '270',
        'city': 'لنگرود',
        'province': 'گیلان'
    },
    {
        'code': '516',
        'city': 'ماسال و شاندرمن',
        'province': 'گیلان'
    },
    {
        'code': '333-334',
        'city': 'اسلام آباد',
        'province': 'کرمانشاه'
    },
    {
        'code': '691',
        'city': 'باینگان',
        'province': 'کرمانشاه'
    },
    {
        'code': '323-322',
        'city': 'پاوه',
        'province': 'کرمانشاه'
    },
    {
        'code': '595',
        'city': 'ثلاث باباجانی',
        'province': 'کرمانشاه'
    },
    {
        'code': '395',
        'city': 'جوانرود',
        'province': 'کرمانشاه'
    },
    {
        'code': '641',
        'city': 'حمیل',
        'province': 'کرمانشاه'
    },
    {
        'code': '596',
        'city': 'روانسر',
        'province': 'کرمانشاه'
    },
    {
        'code': '336',
        'city': 'سرپل ذهاب',
        'province': 'کرمانشاه'
    },
    {
        'code': '335',
        'city': 'سنقر',
        'province': 'کرمانشاه'
    },
    {
        'code': '496',
        'city': 'صحنه',
        'province': 'کرمانشاه'
    },
    {
        'code': '337',
        'city': 'قصرشیرین',
        'province': 'کرمانشاه'
    },
    {
        'code': '324-325',
        'city': 'کرمانشاه',
        'province': 'کرمانشاه'
    },
    {
        'code': '394',
        'city': 'کرند',
        'province': 'کرمانشاه'
    },
    {
        'code': '330',
        'city': 'کنگاور',
        'province': 'کرمانشاه'
    },
    {
        'code': '332',
        'city': 'گیلانغرب',
        'province': 'کرمانشاه'
    },
    {
        'code': '331',
        'city': 'هرسین',
        'province': 'کرمانشاه'
    },
    {
        'code': '687',
        'city': 'باشت',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '422-423',
        'city': 'بویراحمد(یاسوج)',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '599',
        'city': 'بهمنی',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '600',
        'city': 'چاروسا',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '688',
        'city': 'دروهان',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '424-425',
        'city': 'کهکیلویه(دهدشت)',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '426',
        'city': 'گچساران(دوگنبدان)',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '550',
        'city': 'لنده',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '697',
        'city': 'مارگون',
        'province': 'کهکیلویه و بویراحمد'
    },
    {
        'code': '384',
        'city': 'بانه',
        'province': 'کردستان'
    },
    {
        'code': '377-378',
        'city': 'بیجار',
        'province': 'کردستان'
    },
    {
        'code': '558',
        'city': 'دهگلان',
        'province': 'کردستان'
    },
    {
        'code': '385',
        'city': 'دیواندره',
        'province': 'کردستان'
    },
    {
        'code': '646',
        'city': 'سروآباد',
        'province': 'کردستان'
    },
    {
        'code': '375-376',
        'city': 'سقز',
        'province': 'کردستان'
    },
    {
        'code': '372-373',
        'city': 'سنندج',
        'province': 'کردستان'
    },
    {
        'code': '379-380',
        'city': 'قروه',
        'province': 'کردستان'
    },
    {
        'code': '383',
        'city': 'کامیاران',
        'province': 'کردستان'
    },
    {
        'code': '674',
        'city': 'کرانی',
        'province': 'کردستان'
    },
    {
        'code': '381-382',
        'city': 'مریوان',
        'province': 'کردستان'
    },
    {
        'code': '676',
        'city': 'نمشیر',
        'province': 'کردستان'
    },
    {
        'code': '722',
        'city': 'ارزونیه',
        'province': 'کرمان'
    },
    {
        'code': '542',
        'city': 'انار',
        'province': 'کرمان'
    },
    {
        'code': '312-313',
        'city': 'بافت',
        'province': 'کرمان'
    },
    {
        'code': '317',
        'city': 'بردسیر',
        'province': 'کرمان'
    },
    {
        'code': '310-311',
        'city': 'بم',
        'province': 'کرمان'
    },
    {
        'code': '302-303',
        'city': 'جیرفت',
        'province': 'کرمان'
    },
    {
        'code': '583',
        'city': 'رابر',
        'province': 'کرمان'
    },
    {
        'code': '321',
        'city': 'راور',
        'province': 'کرمان'
    },
    {
        'code': '382',
        'city': 'راین',
        'province': 'کرمان'
    },
    {
        'code': '304-305',
        'city': 'رفسنجان',
        'province': 'کرمان'
    },
    {
        'code': '536',
        'city': 'رودبار کهنوج',
        'province': 'کرمان'
    },
    {
        'code': '605',
        'city': 'ریگان',
        'province': 'کرمان'
    },
    {
        'code': '308-309',
        'city': 'زرند',
        'province': 'کرمان'
    },
    {
        'code': '306-307',
        'city': 'سیرجان',
        'province': 'کرمان'
    },
    {
        'code': '319',
        'city': 'شهداد',
        'province': 'کرمان'
    },
    {
        'code': '313-314',
        'city': 'شهربابک',
        'province': 'کرمان'
    },
    {
        'code': '606',
        'city': 'عنبرآباد',
        'province': 'کرمان'
    },
    {
        'code': '320',
        'city': 'فهرج',
        'province': 'کرمان'
    },
    {
        'code': '698',
        'city': 'قلعه گنج',
        'province': 'کرمان'
    },
    {
        'code': '298-299',
        'city': 'کرمان',
        'province': 'کرمان'
    },
    {
        'code': '535',
        'city': 'کوهبنان',
        'province': 'کرمان'
    },
    {
        'code': '315-316',
        'city': 'کهنوج',
        'province': 'کرمان'
    },
    {
        'code': '318',
        'city': 'گلباف',
        'province': 'کرمان'
    },
    {
        'code': '607',
        'city': 'ماهان',
        'province': 'کرمان'
    },
    {
        'code': '608',
        'city': 'منوجان',
        'province': 'کرمان'
    },
    {
        'code': '508',
        'city': 'آبیک',
        'province': 'قزوین'
    },
    {
        'code': '538',
        'city': 'آوج',
        'province': 'قزوین'
    },
    {
        'code': '728',
        'city': 'البرز',
        'province': 'قزوین'
    },
    {
        'code': '509',
        'city': 'بوئین زهرا',
        'province': 'قزوین'
    },
    {
        'code': '438-439',
        'city': 'تاکستان',
        'province': 'قزوین'
    },
    {
        'code': '580',
        'city': 'رودبار الموت',
        'province': 'قزوین'
    },
    {
        'code': '590',
        'city': 'رودبار شهرستان',
        'province': 'قزوین'
    },
    {
        'code': '559',
        'city': 'ضیاءآباد',
        'province': 'قزوین'
    },
    {
        'code': '588',
        'city': 'طارم سفلی',
        'province': 'قزوین'
    },
    {
        'code': '431-432',
        'city': 'قزوین',
        'province': 'قزوین'
    },
    {
        'code': '037-038',
        'city': 'قم',
        'province': 'قم'
    },
    {
        'code': '702',
        'city': 'کهک',
        'province': 'قم'
    },
    {
        'code': '240-241',
        'city': 'آباده',
        'province': 'فارس'
    },
    {
        'code': '670',
        'city': 'آباده طشک',
        'province': 'فارس'
    },
    {
        'code': '648',
        'city': 'ارسنجان',
        'province': 'فارس'
    },
    {
        'code': '252',
        'city': 'استهبان',
        'province': 'فارس'
    },
    {
        'code': '678',
        'city': 'اشکنان',
        'province': 'فارس'
    },
    {
        'code': '253',
        'city': 'اقلید',
        'province': 'فارس'
    },
    {
        'code': '649',
        'city': 'اوز',
        'province': 'فارس'
    },
    {
        'code': '513',
        'city': 'بوانات',
        'province': 'فارس'
    },
    {
        'code': '546',
        'city': 'بیضا',
        'province': 'فارس'
    },
    {
        'code': '671',
        'city': 'جویم',
        'province': 'فارس'
    },
    {
        'code': '246-247',
        'city': 'جهرم',
        'province': 'فارس'
    },
    {
        'code': '654',
        'city': 'حاجی آباد(زرین دشت)',
        'province': 'فارس'
    },
    {
        'code': '548',
        'city': 'خرامه',
        'province': 'فارس'
    },
    {
        'code': '547',
        'city': 'خشت و کمارج',
        'province': 'فارس'
    },
    {
        'code': '655',
        'city': 'خفر',
        'province': 'فارس'
    },
    {
        'code': '248-249',
        'city': 'داراب',
        'province': 'فارس'
    },
    {
        'code': '253',
        'city': 'سپیدان',
        'province': 'فارس'
    },
    {
        'code': '514',
        'city': 'سروستان',
        'province': 'فارس'
    },
    {
        'code': '665',
        'city': 'سعادت آباد',
        'province': 'فارس'
    },
    {
        'code': '673',
        'city': 'شیبکوه',
        'province': 'فارس'
    },
    {
        'code': '228-229-230',
        'city': 'شیراز',
        'province': 'فارس'
    },
    {
        'code': '679',
        'city': 'فراشبند',
        'province': 'فارس'
    },
    {
        'code': '256-257',
        'city': 'فسا',
        'province': 'فارس'
    },
    {
        'code': '244-245',
        'city': 'فیروزآباد',
        'province': 'فارس'
    },
    {
        'code': '681',
        'city': 'قنقری(خرم بید)',
        'province': 'فارس'
    },
    {
        'code': '723',
        'city': 'قیروکارزین',
        'province': 'فارس'
    },
    {
        'code': '236-237',
        'city': 'کازرون',
        'province': 'فارس'
    },
    {
        'code': '683',
        'city': 'کوار',
        'province': 'فارس'
    },
    {
        'code': '656',
        'city': 'کراش',
        'province': 'فارس'
    },
    {
        'code': '250-251',
        'city': 'لارستان',
        'province': 'فارس'
    },
    {
        'code': '515',
        'city': 'لامرد',
        'province': 'فارس'
    },
    {
        'code': '242-243',
        'city': 'مرودشت',
        'province': 'فارس'
    },
    {
        'code': '238-239',
        'city': 'ممسنی',
        'province': 'فارس'
    },
    {
        'code': '657',
        'city': 'مهر',
        'province': 'فارس'
    },
    {
        'code': '255',
        'city': 'نی ریز',
        'province': 'فارس'
    },
    {
        'code': '684',
        'city': 'ایوانکی',
        'province': 'سمنان'
    },
    {
        'code': '700',
        'city': 'بسطام',
        'province': 'سمنان'
    },
    {
        'code': '642',
        'city': 'بیارجمند',
        'province': 'سمنان'
    },
    {
        'code': '457',
        'city': 'دامغان',
        'province': 'سمنان'
    },
    {
        'code': '456',
        'city': 'سمنان',
        'province': 'سمنان'
    },
    {
        'code': '458-459',
        'city': 'شاهرود',
        'province': 'سمنان'
    },
    {
        'code': '460',
        'city': 'گرمسار',
        'province': 'سمنان'
    },
    {
        'code': '530',
        'city': 'مهدیشهر',
        'province': 'سمنان'
    },
    {
        'code': '520',
        'city': 'میامی',
        'province': 'سمنان'
    },
    {
        'code': '358-359',
        'city': 'ایرانشهر',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '682',
        'city': 'بزمان',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '703',
        'city': 'بمپور',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '364-365',
        'city': 'چابهار',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '371',
        'city': 'خاش',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '701',
        'city': 'دشتیاری',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '720',
        'city': 'راسک',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '366-367',
        'city': 'زابل',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '704',
        'city': 'زابلی',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '361-362',
        'city': 'زاهدان',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '369-370',
        'city': 'سراوان',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '635',
        'city': 'سرباز',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '668',
        'city': 'سیب و سوران',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '533',
        'city': 'شهرکی و ناروئی(زهک)',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '705',
        'city': 'شیب آب',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '699',
        'city': 'فنوج',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '669',
        'city': 'قصرقند',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '725',
        'city': 'کنارک',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '597',
        'city': 'لاشار(اسپکه)',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '611',
        'city': 'میرجاوه',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '525',
        'city': 'نیک شهر',
        'province': 'سیستان و بلوچستان'
    },
    {
        'code': '181',
        'city': 'آبادان',
        'province': 'خوزستان'
    },
    {
        'code': '527',
        'city': 'آغاجاری',
        'province': 'خوزستان'
    },
    {
        'code': '585',
        'city': 'اروندکنار',
        'province': 'خوزستان'
    },
    {
        'code': '685',
        'city': 'امیدیه',
        'province': 'خوزستان'
    },
    {
        'code': '663',
        'city': 'اندیکا',
        'province': 'خوزستان'
    },
    {
        'code': '192-193',
        'city': 'اندیمشک',
        'province': 'خوزستان'
    },
    {
        'code': '174-175',
        'city': 'اهواز',
        'province': 'خوزستان'
    },
    {
        'code': '183-184',
        'city': 'ایذه',
        'province': 'خوزستان'
    },
    {
        'code': '481',
        'city': 'باغ ملک',
        'province': 'خوزستان'
    },
    {
        'code': '706',
        'city': 'بندر امام خمینی',
        'province': 'خوزستان'
    },
    {
        'code': '194-195',
        'city': 'بندرماهشهر',
        'province': 'خوزستان'
    },
    {
        'code': '185-186',
        'city': 'بهبهان',
        'province': 'خوزستان'
    },
    {
        'code': '182',
        'city': 'خرمشهر',
        'province': 'خوزستان'
    },
    {
        'code': '199-200',
        'city': 'دزفول',
        'province': 'خوزستان'
    },
    {
        'code': '198',
        'city': 'دشت آزادگان',
        'province': 'خوزستان'
    },
    {
        'code': '662',
        'city': 'رامشیر',
        'province': 'خوزستان'
    },
    {
        'code': '190-191',
        'city': 'رامهرمز',
        'province': 'خوزستان'
    },
    {
        'code': '692',
        'city': 'سردشت',
        'province': 'خوزستان'
    },
    {
        'code': '189',
        'city': 'شادگان',
        'province': 'خوزستان'
    },
    {
        'code': '707',
        'city': 'شاوور',
        'province': 'خوزستان'
    },
    {
        'code': '526',
        'city': 'شوش',
        'province': 'خوزستان'
    },
    {
        'code': '187-188',
        'city': 'شوشتر',
        'province': 'خوزستان'
    },
    {
        'code': '729',
        'city': 'گتوند',
        'province': 'خوزستان'
    },
    {
        'code': '730',
        'city': 'لالی',
        'province': 'خوزستان'
    },
    {
        'code': '196-197',
        'city': 'مسجدسلیمان',
        'province': 'خوزستان'
    },
    {
        'code': '661',
        'city': 'هندیجان',
        'province': 'خوزستان'
    },
    {
        'code': '680',
        'city': 'هویزه',
        'province': 'خوزستان'
    },
    {
        'code': '643',
        'city': 'احمدآباد',
        'province': 'خراسان رضوی'
    },
    {
        'code': '562',
        'city': 'بجستان',
        'province': 'خراسان رضوی'
    },
    {
        'code': '572',
        'city': 'بردسکن',
        'province': 'خراسان رضوی'
    },
    {
        'code': '074',
        'city': 'تایباد',
        'province': 'خراسان رضوی'
    },
    {
        'code': '644',
        'city': 'تخت جلگه',
        'province': 'خراسان رضوی'
    },
    {
        'code': '072-073',
        'city': 'تربت جام',
        'province': 'خراسان رضوی'
    },
    {
        'code': '069-070',
        'city': 'تربت حیدریه',
        'province': 'خراسان رضوی'
    },
    {
        'code': '521',
        'city': 'جغتای',
        'province': 'خراسان رضوی'
    },
    {
        'code': '573',
        'city': 'جوین',
        'province': 'خراسان رضوی'
    },
    {
        'code': '522',
        'city': 'چناران',
        'province': 'خراسان رضوی'
    },
    {
        'code': '724',
        'city': 'خلیل آباد',
        'province': 'خراسان رضوی'
    },
    {
        'code': '076',
        'city': 'خواف',
        'province': 'خراسان رضوی'
    },
    {
        'code': '077',
        'city': 'درگز',
        'province': 'خراسان رضوی'
    },
    {
        'code': '650',
        'city': 'رشتخوار',
        'province': 'خراسان رضوی'
    },
    {
        'code': '574',
        'city': 'زبرخان',
        'province': 'خراسان رضوی'
    },
    {
        'code': '078-079',
        'city': 'سبزوار',
        'province': 'خراسان رضوی'
    },
    {
        'code': '081',
        'city': 'سرخس',
        'province': 'خراسان رضوی'
    },
    {
        'code': '084',
        'city': 'فریمان',
        'province': 'خراسان رضوی'
    },
    {
        'code': '651',
        'city': 'فیض آباد',
        'province': 'خراسان رضوی'
    },
    {
        'code': '086-087',
        'city': 'قوچان',
        'province': 'خراسان رضوی'
    },
    {
        'code': '089-090',
        'city': 'کاشمر',
        'province': 'خراسان رضوی'
    },
    {
        'code': '553',
        'city': 'کلات',
        'province': 'خراسان رضوی'
    },
    {
        'code': '091',
        'city': 'گناباد',
        'province': 'خراسان رضوی'
    },
    {
        'code': '092-093-094',
        'city': 'مشهد',
        'province': 'خراسان رضوی'
    },
    {
        'code': '097',
        'city': 'مشهد منطقه2',
        'province': 'خراسان رضوی'
    },
    {
        'code': '098',
        'city': 'مشهد منطقه3',
        'province': 'خراسان رضوی'
    },
    {
        'code': '096',
        'city': 'مشهد منطقه1',
        'province': 'خراسان رضوی'
    },
    {
        'code': '105-106',
        'city': 'نیشابور',
        'province': 'خراسان رضوی'
    },
    {
        'code': '063',
        'city': 'اسفراین',
        'province': 'خراسان شمالی'
    },
    {
        'code': '067-068',
        'city': 'بجنورد',
        'province': 'خراسان شمالی'
    },
    {
        'code': '075',
        'city': 'جاجرم',
        'province': 'خراسان شمالی'
    },
    {
        'code': '591',
        'city': 'رازوجرکلان',
        'province': 'خراسان شمالی'
    },
    {
        'code': '082',
        'city': 'شیروان',
        'province': 'خراسان شمالی'
    },
    {
        'code': '635',
        'city': 'فاروج',
        'province': 'خراسان شمالی'
    },
    {
        'code': '524',
        'city': 'مانه و سملقان',
        'province': 'خراسان شمالی'
    },
    {
        'code': '468',
        'city': 'اردل',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '465',
        'city': 'بروجن',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '461-462',
        'city': 'شهرکرد',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '467',
        'city': 'فارسان',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '632',
        'city': 'فلارد',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '555',
        'city': 'کوهرنگ',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '633',
        'city': 'کیار',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '629',
        'city': 'گندمان',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '466',
        'city': 'لردگان',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '696',
        'city': 'میانکوه',
        'province': 'چهارمحال و بختیاری'
    },
    {
        'code': '721',
        'city': 'بشرویه',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '064-065',
        'city': 'بیرجند',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '523',
        'city': 'درمیان',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '652',
        'city': 'زیرکوه',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '719',
        'city': 'سرایان',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '716',
        'city': 'سربیشه',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '085',
        'city': 'فردوس',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '088',
        'city': 'قائنات',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '563',
        'city': 'نهبندان',
        'province': 'خراسان جنوبی'
    },
    {
        'code': '529',
        'city': 'بندر دیلم',
        'province': 'بوشهر'
    },
    {
        'code': '353',
        'city': 'بندر گناوه',
        'province': 'بوشهر'
    },
    {
        'code': '349-350',
        'city': 'بوشهر',
        'province': 'بوشهر'
    },
    {
        'code': '355',
        'city': 'تنگستان',
        'province': 'بوشهر'
    },
    {
        'code': '609',
        'city': 'جم',
        'province': 'بوشهر'
    },
    {
        'code': '351-352',
        'city': 'دشتستان',
        'province': 'بوشهر'
    },
    {
        'code': '354',
        'city': 'دشتی',
        'province': 'بوشهر'
    },
    {
        'code': '732',
        'city': 'دلوار',
        'province': 'بوشهر'
    },
    {
        'code': '357',
        'city': 'دیر',
        'province': 'بوشهر'
    },
    {
        'code': '532',
        'city': 'سعد آباد',
        'province': 'بوشهر'
    },
    {
        'code': '610',
        'city': 'شبانکاره',
        'province': 'بوشهر'
    },
    {
        'code': '356',
        'city': 'کنگان',
        'province': 'بوشهر'
    },
    {
        'code': '556',
        'city': 'اسلامشهر',
        'province': 'تهران'
    },
    {
        'code': '658',
        'city': 'پاکدشت',
        'province': 'تهران'
    },
    {
        'code': '001-002-003-004-005-006-007-008',
        'city': 'تهران مرکزی',
        'province': 'تهران'
    },
    {
        'code': '011',
        'city': 'تهران جنوب',
        'province': 'تهران'
    },
    {
        'code': '020',
        'city': 'تهران شرق',
        'province': 'تهران'
    },
    {
        'code': '025',
        'city': 'تهرانشمال',
        'province': 'تهران'
    },
    {
        'code': '015',
        'city': 'تهران غرب',
        'province': 'تهران'
    },
    {
        'code': '043',
        'city': 'دماوند',
        'province': 'تهران'
    },
    {
        'code': '666',
        'city': 'رباط کریم',
        'province': 'تهران'
    },
    {
        'code': '489',
        'city': 'ساوجبلاغ',
        'province': 'تهران'
    },
    {
        'code': '044-045',
        'city': 'شمیران',
        'province': 'تهران'
    },
    {
        'code': '048-049',
        'city': 'شهرری',
        'province': 'تهران'
    },
    {
        'code': '490-491',
        'city': 'شهریار',
        'province': 'تهران'
    },
    {
        'code': '695',
        'city': 'طالقان',
        'province': 'تهران'
    },
    {
        'code': '659',
        'city': 'فیروزکوه',
        'province': 'تهران'
    },
    {
        'code': '031-032',
        'city': 'کرج',
        'province': 'تهران'
    },
    {
        'code': '664',
        'city': 'کهریزک',
        'province': 'تهران'
    },
    {
        'code': '717',
        'city': 'نظرآباد',
        'province': 'تهران'
    },
    {
        'code': '041-042',
        'city': 'ورامین',
        'province': 'تهران'
    },
    {
        'code': '471-472',
        'city': 'امور خارجه',
        'province': 'امور خارجه'
    },
    {
        'code': '454',
        'city': 'آبدانان',
        'province': 'ایلام'
    },
    {
        'code': '581',
        'city': 'ارکوازی(ملکشاهی)',
        'province': 'ایلام'
    },
    {
        'code': '449-450',
        'city': 'ایلام',
        'province': 'ایلام'
    },
    {
        'code': '616',
        'city': 'ایوان',
        'province': 'ایلام'
    },
    {
        'code': '534',
        'city': 'بدره',
        'province': 'ایلام'
    },
    {
        'code': '455',
        'city': 'دره شهر',
        'province': 'ایلام'
    },
    {
        'code': '451',
        'city': 'دهلران',
        'province': 'ایلام'
    },
    {
        'code': '726',
        'city': 'زرین آباد',
        'province': 'ایلام'
    },
    {
        'code': '634',
        'city': 'شیروان لومار',
        'province': 'ایلام'
    },
    {
        'code': '453',
        'city': 'شیروان و چرداول',
        'province': 'ایلام'
    },
    {
        'code': '727',
        'city': 'موسیان',
        'province': 'ایلام'
    },
    {
        'code': '452',
        'city': 'مهران',
        'province': 'ایلام'
    },
    {
        'code': '145-146',
        'city': 'اردبیل',
        'province': 'اردبیل'
    },
    {
        'code': '731',
        'city': 'ارشق',
        'province': 'اردبیل'
    },
    {
        'code': '690',
        'city': 'انگوت',
        'province': 'اردبیل'
    },
    {
        'code': '601',
        'city': 'بیله سوار',
        'province': 'اردبیل'
    },
    {
        'code': '504',
        'city': 'پارس آباد',
        'province': 'اردبیل'
    },
    {
        'code': '163',
        'city': 'خلخال',
        'province': 'اردبیل'
    },
    {
        'code': '714',
        'city': 'خورش رستم',
        'province': 'اردبیل'
    },
    {
        'code': '715',
        'city': 'سرعین',
        'province': 'اردبیل'
    },
    {
        'code': '566',
        'city': 'سنجبد(کوثر)',
        'province': 'اردبیل'
    },
    {
        'code': '166-167',
        'city': 'مشکین شهر',
        'province': 'اردبیل'
    },
    {
        'code': '161-162',
        'city': 'مغان',
        'province': 'اردبیل'
    },
    {
        'code': '686',
        'city': 'نمین',
        'province': 'اردبیل'
    },
    {
        'code': '603',
        'city': 'نیر',
        'province': 'اردبیل'
    },
    {
        'code': '619',
        'city': 'آران و بیدگل',
        'province': 'اصفهان'
    },
    {
        'code': '118',
        'city': 'اردستان',
        'province': 'اصفهان'
    },
    {
        'code': '127-128-129',
        'city': 'اصفهان',
        'province': 'اصفهان'
    },
    {
        'code': '620',
        'city': 'باغ بهادران',
        'province': 'اصفهان'
    },
    {
        'code': '621',
        'city': 'بوئین و میاندشت',
        'province': 'اصفهان'
    },
    {
        'code': '549',
        'city': 'تیران و کرون',
        'province': 'اصفهان'
    },
    {
        'code': '564',
        'city': 'جرقویه',
        'province': 'اصفهان'
    },
    {
        'code': '575',
        'city': 'چادگان',
        'province': 'اصفهان'
    },
    {
        'code': '113-114',
        'city': 'خمینی شهر',
        'province': 'اصفهان'
    },
    {
        'code': '122',
        'city': 'خوانسار',
        'province': 'اصفهان'
    },
    {
        'code': '540',
        'city': 'خور و بیابانک',
        'province': 'اصفهان'
    },
    {
        'code': '660',
        'city': 'دولت آباد',
        'province': 'اصفهان'
    },
    {
        'code': '120',
        'city': 'سمیرم',
        'province': 'اصفهان'
    },
    {
        'code': '512',
        'city': 'سمیرم سفلی (دهاقان)',
        'province': 'اصفهان'
    },
    {
        'code': '510-511',
        'city': 'شاهین شهر',
        'province': 'اصفهان'
    },
    {
        'code': '119',
        'city': 'شهرضا',
        'province': 'اصفهان'
    },
    {
        'code': '115',
        'city': 'فریدن',
        'province': 'اصفهان'
    },
    {
        'code': '112',
        'city': 'فریدونشهر',
        'province': 'اصفهان'
    },
    {
        'code': '110-111',
        'city': 'فلاورجان',
        'province': 'اصفهان'
    },
    {
        'code': '125-126',
        'city': 'کاشان',
        'province': 'اصفهان'
    },
    {
        'code': '565',
        'city': 'کوهپایه',
        'province': 'اصفهان'
    },
    {
        'code': '121',
        'city': 'گلپایگان',
        'province': 'اصفهان'
    },
    {
        'code': '116-117',
        'city': 'لنجان(زرینشهر)',
        'province': 'اصفهان'
    },
    {
        'code': '541',
        'city': 'مبارکه',
        'province': 'اصفهان'
    },
    {
        'code': '622',
        'city': 'میمه',
        'province': 'اصفهان'
    },
    {
        'code': '124',
        'city': 'نائین',
        'province': 'اصفهان'
    },
    {
        'code': '108-109',
        'city': 'نجف آباد',
        'province': 'اصفهان'
    },
    {
        'code': '123',
        'city': 'نطنز',
        'province': 'اصفهان'
    },
    {
        'code': '428-427',
        'city': 'زنجان',
        'province': 'اصفهان'
    },
    {
        'code': '507',
        'city': 'ملکان',
        'province': 'اصفهان'
    },
    {
        'code': '158',
        'city': 'مرند',
        'province': 'اصفهان'
    },
    {
        'code': '615',
        'city': 'ابهر',
        'province': 'اصفهان'
    },
    {
        'code': '615',
        'city': 'خرمدره',
        'province': 'اصفهان'
    },
    {
        'code': '152-153',
        'city': 'میانه',
        'province': 'اصفهان'
    },
]
